import pickle

import pandas as pd
from sklearn.ensemble import RandomForestClassifier
from sklearn.linear_model import LinearRegression


def build_model(model_type: str):
    if model_type == "RandomForestClassifier":
        model = RandomForestClassifier(n_estimators=100, random_state=30)
    else:
        raise RuntimeError(f"Bad model_type -- {model_type}")
    return model


def train_model(features: pd.DataFrame, target: pd.Series, model_type: str):
    model = build_model(model_type)
    model.fit(features, target)
    
    return model


def serialize_model(model: object, output: str) -> str:
    with open(output, "wb") as f:
        pickle.dump(model, f)
    return output



from setuptools import find_packages, setup


setup(
    name="ml_python_package",
    packages=find_packages(),
    version="0.1.5",
    description="Training stuff",
    author="Mikhail Maryufich",
    install_requires=["scikit-learn==0.24.1", "pandas==1.1.5",],
    license="MIT",
)
